@@ -2,14 +2,19 @@
 from minpower import powersystems
 from minpower.optimization import value
 from minpower.commonscripts import Series
+from minpower.config import user_config
 
-from test_utils import *
+from ipdb import set_trace
+from test_utils import (istest, get_duals, with_setup, reset_config,
+    make_cheap_gen, make_mid_gen, make_expensive_gen, 
+    singletime, make_loads_times, 
+    solve_problem)
 
 def test_config():
     assert(user_config.duals == False)
     
 @istest
-@with_setup(get_duals)
+@with_setup(get_duals, reset_config)
 def line_limit_high():
     '''
     Create a two bus system
@@ -24,16 +29,18 @@ def line_limit_high():
     generators=[
         make_cheap_gen(bus='A'),
         make_expensive_gen(bus='B')
-    ]    
+    ]
+    
     lines=[powersystems.Line(pmax=pmax, frombus='A', tobus='B')]
-    power_system,times=solve_problem(generators, lines=lines, **make_loads_times(Pd=225,bus='B'))
+    power_system, times = solve_problem(generators, do_reset_config=False,
+        lines=lines, **make_loads_times(Pd=225,bus='B'))
     Pline = value(lines[0].power(times[0]))
     lmps = [b.price(times[0]) for b in power_system.buses]
     congestion_price = lines[0].price(times[0])
     assert Pline == pmax and congestion_price == (lmps[1] - lmps[0])
 
 @istest
-@with_setup(get_duals)
+@with_setup(get_duals, reset_config)
 def line_limit_low():
     '''
     Create a two bus system
@@ -50,7 +57,8 @@ def line_limit_low():
         make_expensive_gen(bus='B')
     ]    
     lines=[powersystems.Line(pmin=pmin, frombus='B', tobus='A')]
-    power_system,times=solve_problem(generators,lines=lines, **make_loads_times(Pd=225,bus='B'))
+    power_system,times=solve_problem(generators, do_reset_config=False,
+        lines=lines, **make_loads_times(Pd=225,bus='B'))
     Pline = lines[0].power(times[0])
     lmps=[b.price(times[0]) for b in power_system.buses]
     congestion_price = lines[0].price(times[0])
@@ -58,7 +66,7 @@ def line_limit_low():
 
 
 @istest
-@with_setup(get_duals)
+@with_setup(get_duals, reset_config)
 def three_buses():
     '''
     Create a three bus system
@@ -88,7 +96,8 @@ def three_buses():
         powersystems.Line(frombus='A', tobus='C', pmax=pmax),
         powersystems.Line(frombus='B', tobus='C', pmax=pmax),
         ]
-    power_system,times=solve_problem(generators,times=singletime,loads=loads,lines=lines)
+    power_system,times=solve_problem(generators, do_reset_config=False,
+        times=singletime,loads=loads,lines=lines)
     num_lmps=len(set(b.price(times[0]) for b in power_system.buses))
     total_load = value(sum(b.Pload(times[0]) for b in power_system.buses))
     assert total_load==sum(Pd) and num_lmps>1
